@@ -35,13 +35,12 @@ Main entry point for EasyBuild: build software from .eb input file
 @author: Ward Poelmans (Ghent University)
 @author: Fotis Georgatos (University of Luxembourg)
 """
-
 import copy
 import os
 import subprocess
 import sys
 import tempfile
-from vsc import fancylogger
+from vsc.utils import fancylogger
 from vsc.utils.missing import any
 
 # IMPORTANT this has to be the first easybuild import as it customises the logging
@@ -50,22 +49,68 @@ from easybuild.tools.build_log import EasyBuildError, print_msg, print_error
 
 import easybuild.tools.config as config
 import easybuild.tools.options as eboptions
-from easybuild.framework.easyblock import EasyBlock, build_and_install_software
+from easybuild.framework.easyblock import EasyBlock, build_and_install_one
 from easybuild.framework.easyconfig.easyconfig import process_easyconfig
 from easybuild.framework.easyconfig.tools import dep_graph, get_paths_for, print_dry_run
 from easybuild.framework.easyconfig.tools import resolve_dependencies, skip_available
 from easybuild.framework.easyconfig.tweak import obtain_path, tweak
 from easybuild.tools.config import get_repository, module_classes, get_repositorypath, set_tmpdir
-from easybuild.tools.filetools import cleanup, find_easyconfigs, search_file
+from easybuild.tools.filetools import cleanup, find_easyconfigs, search_file, write_file
+from easybuild.tools.github import fetch_easyconfigs_from_pr
 from easybuild.tools.options import process_software_build_specs
-from easybuild.tools.parallelbuild import build_easyconfigs_in_parallel, regtest
-from easybuild.tools.repository import init_repository
+from easybuild.tools.parallelbuild import build_easyconfigs_in_parallel
+from easybuild.tools.repository.repository import init_repository
+from easybuild.tools.testing import create_test_report, post_easyconfigs_pr_test_report, upload_test_report_as_gist
+from easybuild.tools.testing import regtest, session_module_list, session_state
+from easybuild.tools.toolchain import DUMMY_TOOLCHAIN_NAME
 from easybuild.tools.version import this_is_easybuild  # from a single location
 
 
 _log = None
 
 
+def build_and_install_software(ecs, init_session_state, exit_on_failure=True):
+    """Build and install software for all provided parsed easyconfig files."""
+    # obtain a copy of the starting environment so each build can start afresh
+    # we shouldn't use the environment from init_session_state, since relevant env vars might have been set since
+    # e.g. via easyconfig.handle_allowed_system_deps
+    orig_environ = copy.deepcopy(os.environ)
+
+    res = []
+    for ec in ecs:
+        ec_res = {}
+        try:
+            (ec_res['success'], app_log, err) = build_and_install_one(ec, orig_environ)
+            ec_res['log_file'] = app_log
+            if not ec_res['success']:
+                ec_res['err'] = EasyBuildError(err)
+        except Exception, err:
+            # purposely catch all exceptions
+            ec_res['success'] = False
+            ec_res['err'] = err
+
+        # keep track of success/total count
+        if ec_res['success']:
+            test_msg = "Successfully built %s" % ec['spec']
+        else:
+            test_msg = "Build of %s failed" % ec['spec']
+            if 'err' in ec_res:
+                test_msg += " (err: %s)" % ec_res['err']
+
+        # dump test report next to log file
+        test_report_txt = create_test_report(test_msg, [(ec, ec_res)], init_session_state)
+        if 'log_file' in ec_res:
+            test_report_fp = "%s_test_report.md" % '.'.join(ec_res['log_file'].split('.')[:-1])
+            write_file(test_report_fp, test_report_txt)
+
+        if not ec_res['success'] and exit_on_failure:
+            _log.error(test_msg)
+
+        res.append((ec, ec_res))
+
+    return res
+
+
 def main(testing_data=(None, None, None)):
     """
     Main function:
@@ -74,6 +119,10 @@ def main(testing_data=(None, None, None)):
     - read easyconfig
     - build software
     """
+
+    # purposely session state very early, to avoid modules loaded by EasyBuild meddling in
+    init_session_state = session_state()
+
     # disallow running EasyBuild as root
     if os.getuid() == 0:
         sys.stderr.write("ERROR: You seem to be running EasyBuild with root privileges.\n"
@@ -89,6 +138,8 @@ def main(testing_data=(None, None, None)):
     eb_go = eboptions.parse_options(args=args)
     options = eb_go.options
     orig_paths = eb_go.args
+    eb_config = eb_go.generate_cmd_line(add_default=True)
+    init_session_state.update({'easybuild_configuration': eb_config})
 
     # set umask (as early as possible)
     if options.umask is not None:
@@ -143,8 +194,15 @@ def main(testing_data=(None, None, None)):
     if not easyconfigs_paths:
         _log.warning("Failed to determine install path for easybuild-easyconfigs package.")
 
+    # process software build specifications (if any), i.e.
+    # software name/version, toolchain name/version, extra patches, ...
+    (try_to_generate, build_specs) = process_software_build_specs(options)
+
     # specified robot paths are preferred over installed easyconfig files
-    if robot_path:
+    # --try-X and --dep-graph both require --robot, so enable it with path of installed easyconfigs
+    if robot_path or try_to_generate or options.dep_graph:
+        if robot_path is None:
+            robot_path = []
         robot_path.extend(easyconfigs_paths)
         easyconfigs_paths = robot_path[:]
         _log.info("Extended list of robot paths with paths for installed easyconfigs: %s" % robot_path)
@@ -164,18 +222,19 @@ def main(testing_data=(None, None, None)):
         'aggregate_regtest': options.aggregate_regtest,
         'allow_modules_tool_mismatch': options.allow_modules_tool_mismatch,
         'check_osdeps': not options.ignore_osdeps,
+        'cleanup_builddir': options.cleanup_builddir,
         'command_line': eb_command_line,
         'debug': options.debug,
         'dry_run': options.dry_run,
         'easyblock': options.easyblock,
         'experimental': options.experimental,
         'force': options.force,
+        'github_user': options.github_user,
         'group': options.group,
         'ignore_dirs': options.ignore_dirs,
         'modules_footer': options.modules_footer,
         'only_blocks': options.only_blocks,
         'recursive_mod_unload': options.recursive_module_unload,
-        'regtest_online': options.regtest_online,
         'regtest_output_dir': options.regtest_output_dir,
         'retain_all_deps': retain_all_deps,
         'robot_path': robot_path,
@@ -192,6 +251,11 @@ def main(testing_data=(None, None, None)):
         'validate': not options.force,
     })
 
+    # obtain list of loaded modules, build options must be initialized first
+    modlist = session_module_list()
+    init_session_state.update({'module_list': modlist})
+    _log.debug("Initial session state: %s" % init_session_state)
+
     # search for easyconfigs
     if options.search or options.search_short:
         search_path = [os.getcwd()]
@@ -202,13 +266,13 @@ def main(testing_data=(None, None, None)):
         silent = config.build_option('silent')
         search_file(search_path, query, short=not options.search, ignore_dirs=ignore_dirs, silent=silent)
 
-    # process software build specifications (if any), i.e.
-    # software name/version, toolchain name/version, extra patches, ...
-    (try_to_generate, build_specs) = process_software_build_specs(options)
-
     paths = []
     if len(orig_paths) == 0:
-        if 'name' in build_specs:
+        if options.from_pr:
+            pr_path = os.path.join(eb_tmpdir, "files_pr%s" % options.from_pr)
+            pr_files = fetch_easyconfigs_from_pr(options.from_pr, path=pr_path, github_user=options.github_user)
+            paths = [(path, False) for path in pr_files if path.endswith('.eb')]
+        elif 'name' in build_specs:
             paths = [obtain_path(build_specs, easyconfigs_paths, try_to_generate=try_to_generate,
                                  exit_on_error=not testing)]
         elif not any([options.aggregate_regtest, options.search, options.search_short, options.regtest]):
@@ -275,19 +339,22 @@ def main(testing_data=(None, None, None)):
             print_error("Can't find path %s" % path)
 
         try:
-            files = find_easyconfigs(path, ignore_dirs=options.ignore_dirs)
-            for f in files:
-                if not generated and try_to_generate and build_specs:
-                    ec_file = tweak(f, None, build_specs)
+            ec_files = find_easyconfigs(path, ignore_dirs=options.ignore_dirs)
+            for ec_file in ec_files:
+                # only pass build specs when not generating easyconfig files
+                if try_to_generate:
+                    ecs = process_easyconfig(ec_file)
                 else:
-                    ec_file = f
-                ecs = process_easyconfig(ec_file, build_specs=build_specs)
+                    ecs = process_easyconfig(ec_file, build_specs=build_specs)
                 easyconfigs.extend(ecs)
         except IOError, err:
             _log.error("Processing easyconfigs in path %s failed: %s" % (path, err))
 
+    # tweak obtained easyconfig files, if requested
+    if try_to_generate and build_specs:
+        easyconfigs = tweak(easyconfigs, build_specs)
+
     # before building starts, take snapshot of environment (watch out -t option!)
-    orig_environ = copy.deepcopy(os.environ)
     os.chdir(os.environ['PWD'])
 
     # dry_run: print all easyconfigs and dependencies, and whether they are already built
@@ -336,41 +403,57 @@ def main(testing_data=(None, None, None)):
             txt.extend(["%s (%s): %s" % (job.name, job.module, job.jobid) for job in jobs])
             txt.append("(%d jobs submitted)" % len(jobs))
 
-            msg = "\n".join(txt)
-            _log.info("Submitted parallel build jobs, exiting now (%s)." % msg)
-            print msg
-
+            print_msg("Submitted parallel build jobs, exiting now: %s" % '\n'.join(txt), log=_log)
             cleanup(logfile, eb_tmpdir, testing)
-
             sys.exit(0)
 
-    # build software, will exit when errors occurs (except when regtesting)
-    correct_built_cnt = 0
-    all_built_cnt = 0
+    # build software, will exit when errors occurs (except when testing)
+    exit_on_failure = not options.dump_test_report and not options.upload_test_report
     if not testing or (testing and do_build):
-        for ec in ordered_ecs:
-            (success, _) = build_and_install_software(ec, orig_environ)
-            if success:
-                correct_built_cnt += 1
-            all_built_cnt += 1
+        ecs_with_res = build_and_install_software(ordered_ecs, init_session_state, exit_on_failure=exit_on_failure)
+    else:
+        ecs_with_res = [(ec, {}) for ec in ordered_ecs]
 
-    print_msg("Build succeeded for %s out of %s" % (correct_built_cnt, all_built_cnt), log=_log, silent=testing)
+    correct_builds_cnt = len([ec_res for (_, ec_res) in ecs_with_res if ec_res.get('success', False)])
+    overall_success = correct_builds_cnt == len(ordered_ecs)
+    success_msg = "Build succeeded for %s out of %s" % (correct_builds_cnt, len(ordered_ecs))
 
     repo = init_repository(get_repository(), get_repositorypath())
     repo.cleanup()
 
+    # report back in PR in case of testing
+    if options.upload_test_report:
+        msg = success_msg + " (%d easyconfigs in this PR)" % len(paths)
+        test_report = create_test_report(msg, ecs_with_res, init_session_state, pr_nr=options.from_pr, gist_log=True)
+        if options.from_pr:
+            # upload test report to gist and issue a comment in the PR to notify
+            msg = post_easyconfigs_pr_test_report(options.from_pr, test_report, success_msg, init_session_state, overall_success)
+            print_msg(msg)
+        else:
+            # only upload test report as a gist
+            gist_url = upload_test_report_as_gist(test_report)
+            print_msg("Test report uploaded to %s" % gist_url)
+    else:
+        test_report = create_test_report(success_msg, ecs_with_res, init_session_state)
+    _log.debug("Test report: %s" % test_report)
+    if options.dump_test_report is not None:
+        write_file(options.dump_test_report, test_report)
+        _log.info("Test report dumped to %s" % options.dump_test_report)
+
+    print_msg(success_msg, log=_log, silent=testing)
+
     # cleanup and spec files
     for ec in easyconfigs:
         if 'original_spec' in ec and os.path.isfile(ec['spec']):
             os.remove(ec['spec'])
 
-    # cleanup tmp log file (all is well, all modules have their own log file)
+    # cleanup tmp log file, unless one build failed (individual logs are located in eb_tmpdir path)
     if options.logtostdout:
         fancylogger.logToScreen(enable=False, stdout=True)
     else:
         fancylogger.logToFile(logfile, enable=False)
-    cleanup(logfile, eb_tmpdir, testing)
-
+    if overall_success:
+        cleanup(logfile, eb_tmpdir, testing)
 
 if __name__ == "__main__":
     try:
