@@ -34,7 +34,7 @@ import shutil
 import sys
 import tempfile
 from unittest import TestCase
-from vsc import fancylogger
+from vsc.utils import fancylogger
 
 import easybuild.tools.options as eboptions
 from easybuild.framework.easyblock import EasyBlock
@@ -52,7 +52,7 @@ class EnhancedTestCase(TestCase):
         """Convenience method to match regex with the expected error message"""
         try:
             call(*args, **kwargs)
-            str_kwargs = ', '.join(['='.join([k, str(v)]) for (k, v) in kwargs.items()])
+            str_kwargs = ', '.join(['='.join([k,str(v)]) for (k,v) in kwargs.items()])
             str_args = ', '.join(map(str, args) + [str_kwargs])
             self.assertTrue(False, "Expected errors with %s(%s) call should occur" % (call.__name__, str_args))
         except error, err:
@@ -61,9 +61,14 @@ class EnhancedTestCase(TestCase):
             elif hasattr(err, 'message'):
                 msg = err.message
             elif hasattr(err, 'args'):  # KeyError in Python 2.4 only provides message via 'args' attribute
-                msg = str(err.args[0])
+                msg = err.args[0]
             else:
-                msg = str(err)
+                msg = err
+            try:
+                msg = str(msg)
+            except UnicodeEncodeError:
+                msg = msg.encode('utf8', 'replace')
+            self.assertTrue(re.search(regex, msg), "Pattern '%s' is found in '%s'" % (regex, msg))
             self.assertTrue(re.search(regex, msg), "Pattern '%s' is found in '%s'" % (regex, msg))
 
     def setUp(self):
@@ -130,7 +135,7 @@ class EnhancedTestCase(TestCase):
                     del os.environ['EASYBUILD_%s' % path.upper()]
         init_config()
 
-    def eb_main(self, args, do_build=False, return_error=False, logfile=None, verbose=False):
+    def eb_main(self, args, do_build=False, return_error=False, logfile=None, verbose=False, raise_error=False):
         """Helper method to call EasyBuild main function."""
         # clear instance of BuildOptions and ConfigurationVariables to ensure configuration is reinitialized
         config.ConfigurationVariables.__metaclass__._instances.pop(config.ConfigurationVariables, None)
@@ -149,6 +154,12 @@ class EnhancedTestCase(TestCase):
 
         os.chdir(self.cwd)
 
+        # make sure config is reinitialized
+        init_config()
+
+        if myerr and raise_error:
+            raise myerr
+
         if return_error:
             return read_file(self.logfile), myerr
         else:
@@ -166,6 +177,7 @@ def init_config(args=None, build_options=None):
     eb_go = eboptions.parse_options(args=args)
     config.init(eb_go.options, eb_go.get_options_by_section('config'))
 
+    # initialize build options
     if build_options is None:
         build_options = {
             'valid_module_classes': module_classes(),
