@@ -178,13 +178,13 @@ class FancyLogger(logging.getLoggerClass()):
         """
         overwrite make record to use a fancy record (with more options)
         """
-        if hasattr(msg, 'decode'):
-            new_msg = msg.decode('utf8', 'replace')
-        else:
-            new_msg = msg
         logrecordcls = logging.LogRecord
-        if self.fancyrecord:
+        if hasattr(self, 'fancyrecord') and self.fancyrecord:
             logrecordcls = FancyLogRecord
+        try:
+            new_msg = str(msg)
+        except UnicodeEncodeError:
+            new_msg = msg.encode('utf8', 'replace')
         return logrecordcls(name, level, pathname, lineno, new_msg, args, excinfo)
 
     def raiseException(self, message, exception=None, catch=False):
@@ -227,7 +227,7 @@ class FancyLogger(logging.getLoggerClass()):
         loose_cv.version = loose_cv.version[:depth]
         loose_mv.version = loose_mv.version[:depth]
 
-        if loose_cv > loose_mv:
+        if loose_cv >= loose_mv:
             self.raiseException("DEPRECATED (since v%s) functionality used: %s" % (max_ver, msg), exception=exception)
         else:
             deprecation_msg = "Deprecated functionality, will no longer work in v%s: %s" % (max_ver, msg)
